==> familia_0.1.tar.gz: familia/src/file/file.h <==
/****************************************************************************
 *  Familia Lignum - Genealogical program                                   *
 *  Copyright (C) 2011-2012 Rafał Długołęcki <rafal@dlugolecki.net.pl>      *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or modify    *
 *  it under the terms of the GNU General Public License as published by    *
 *  the Free Software Foundation; version 2 of the License.                 *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License along *
 *  with this program; if not, write to the Free Software Foundation, Inc., *
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.             *
 *                                                                          *
 ****************************************************************************/

#ifndef _BASIC_FILE_H
#define _BASIC_FILE_H

#include <iostream>
#include <istream>
#include <string>
#include <map>
#include <glibmm/ustring.h>

//#include "loader.h"
#include "individual.h"
#include "family.h"
#include "view.h"

namespace file {

class File {
public:
  typedef Glib::ustring _String;
  typedef Individual _Individual;
  typedef Family _Family;
  typedef FileView _View;
  //map: id => individual
  typedef std::map<int, _Individual> _Individuals;
  //map: id => family
  typedef std::map<int, _Family> _Families;
  typedef std::vector<_View> _Views;

public:
  File(const _String filename);
  virtual ~File();

  struct {
    Glib::ustring name;
    Glib::ustring version;
  } software;

  _Individuals individuals;
  _Families families;
  std::vector<_View> views;
};

};

#endif

==> familia_0.1.2.tar.gz: familia/src/file/file.h <==
/****************************************************************************
 *  Familia Lignum - Genealogical program                                   *
 *  Copyright (C) 2011-2012 Rafał Długołęcki <rafal@dlugolecki.net.pl>      *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or modify    *
 *  it under the terms of the GNU General Public License as published by    *
 *  the Free Software Foundation; version 2 of the License.                 *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License along *
 *  with this program; if not, write to the Free Software Foundation, Inc., *
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.             *
 *                                                                          *
 ****************************************************************************/

#ifndef _BASIC_FILE_H
#define _BASIC_FILE_H

#include <iostream>
#include <istream>
#include <string>
#include <map>
#include <glibmm/ustring.h>

//#include "loader.h"
#include "individual.h"
#include "family.h"
#include "view.h"

namespace file {

class File {
public:
  typedef Glib::ustring String;
  typedef Individual _Individual;
  typedef Family _Family;
  typedef FileView _View;
  typedef std::vector<_Individual> Individuals;
  typedef std::vector<_Family> Families;
  typedef std::vector<_View> Views;

public:
  File(const String filepath);
  virtual ~File();

  struct {
    String path;
    String extension;
    String name;
  } details;

  struct {
    String name;
    String version;
  } software;

  Individuals individuals;
  Families families;
  Views views;

protected:
  virtual bool on_draw(const Cairo::RefPtr<Cairo::Context>& cr);
};

};

#endif
